#!/usr/bin/env bash

if true
then

    echo "Before here-doc"

    # Insert 2 lines in file, then save.
    #--------Begin here document-----------#
    vi $TARGETFILE <<x23LimitStringx23
i
This is line 1 of the example file.
This is line 2 of the example file.
^[
ZZ
x23LimitStringx23
    #----------End here document-----------#

    echo "After here-doc"

fi
